# Installation

The instructions below will help you to properly install the generated package to the lavalite project.

## Location

Extract the package contents to the folder 

`/packages/testehost/academy/`

## Composer

Add the below entries in the `composer.json` file's autoload section and run the command `composer dump-autoload` in terminal.

```json

...
     "autoload": {

        "psr-4": {
            ... ,
            "Testehost\\Academy\\": "packages/testehost/academy/src",
            "Testehost\\Academy\\Seeders\\": "packages/testehost/academy/database/seeders"
            
            ...
        }
    },
...

```

## Config

Add the entries in service provider in `config/app.php`

```php

...
    'providers'       => [
        ...
        
        Testehost\Academy\Providers\AcademyServiceProvider::class,
        
        ...
    ],

    ...

    'alias'             => [
        ...
        
        'Academy'  => Testehost\Academy\Facades\Academy::class,
        
        ...
    ]
...

```

## Migrate

After service provider is set run the commapnd to migrate and seed the database.


    php artisan migrate
    php artisan db:seed --class=Testehost\\Academy\\Seeders\\AcademyTableSeeder

## Publishing


**Publishing configuration**

    php artisan vendor:publish --provider="Testehost\Academy\Providers\AcademyServiceProvider" --tag="config"

**Publishing language**

    php artisan vendor:publish --provider="Testehost\Academy\Providers\AcademyServiceProvider" --tag="lang"

**Publishing views**

    php artisan vendor:publish --provider="Testehost\Academy\Providers\AcademyServiceProvider" --tag="view"


## URLs and APIs


### Web Urls

**Admin**

    http://path-to-route-folder/admin/academy/{modulename}

**User**

    http://path-to-route-folder/user/academy/{modulename}

**Public**

    http://path-to-route-folder/academies


### API endpoints

**List**
 
    http://path-to-route-folder/api/user/academy/{modulename}
    METHOD: GET

**Create**

    http://path-to-route-folder/api/user/academy/{modulename}
    METHOD: POST

**Edit**

    http://path-to-route-folder/api/user/academy/{modulename}/{id}
    METHOD: PUT

**Delete**

    http://path-to-route-folder/api/user/academy/{modulename}/{id}
    METHOD: DELETE

**Public List**

    http://path-to-route-folder/api/academy/{modulename}
    METHOD: GET

**Public Single**

    http://path-to-route-folder/api/academy/{modulename}/{slug}
    METHOD: GET